@@ -1,6 +1,8 @@
 <?php
 function _addKeywords(&$tof,$vars) {
-	$tof->addKeywords(
+	require_once("actions/keywords.php");
+	addKeywords(
+		$tof,
 		$vars['Pictures'],
 		$vars['TypeID'],
 		$vars['KeywordValue']);
