@@ -1,6 +1,8 @@
 <?php
 function _addUser(&$tof,$vars) {
-	$tof->addUser(
+	require_once("actions/user.php");
+	addUser(
+		$tof,
 		array('Username' => $vars['Username'],
 			  'Password' => $vars['Password'],
 			  'Name' => $vars['Name'],
