@@ -1,6 +1,8 @@
 <?php
 function _deleteUser(&$tof,$vars) {
-	$tof->deleteUser(
+	require_once("actions/user.php");
+	deleteUser(
+		$tof,
 		$vars['UserID'],
 		$vars['RemovePictures'],
 		$vars['DeleteFiles']);
