@@ -8,7 +8,7 @@ function clearSelectionTopics(&$tof) {
 
 function setSelectionTopics(&$tof,$topics) {
 	require_once("actions/addSelectionToTopic.php");
-	$tof->clearSelectionTopics();
+	clearSelectionTopics($tof);
 	foreach($topics as $topicID) {
 		addSelectionToTopic($tof,$topicID);
 	}
