@@ -9,17 +9,20 @@ function _setSelectionGroups(&$tof,$vars) {
 }
 
 function setSelectionGroups(&$tof,$groups) {
+	require_once("actions/updatePictures.php");
 	$selection = $tof->ct->getSelection($tof->uid);
-	$tof->updatePictures("unchanged",$groups,$selection);
+	updatePictures($tof,"unchanged",$groups,$selection);
 }
 
 function addGroupsToSelection(&$tof,$groups) {
+	require_once("actions/groups.php");
 	$selection = $tof->ct->getSelection($tof->uid);
-	$tof->addGroupsToPictures($groups,$selection);
+	addGroupsToPictures($tof,$groups,$selection);
 }
 
 function removeGroupsFromSelection(&$tof,$groups) {
+	require_once("actions/groups.php");
 	$selection = $tof->ct->getSelection($tof->uid);
-	$tof->removeGroupsFromPictures($groups,$selection);
+	removeGroupsFromPictures($tof,$groups,$selection);
 }
 ?>
\ No newline at end of file
