@@ -4,7 +4,8 @@ function _setSelectionTopic(&$tof,$vars) {
 }
 
 function setSelectionTopic(&$tof,$topicID) {
+	require_once("actions/updatePictures.php");
 	$selection = $tof->ct->getSelection($tof->uid);
-	$tof->updatePictures($topicID,"unchanged",$selection);
+	updatePictures($tof,$topicID,"unchanged",$selection);
 }
 ?>
\ No newline at end of file
