@@ -1,8 +1,7 @@
 <?php
-function maybeCreateTopic(&$tof,$topicID, $description) {
+function maybeCreateTopic(&$tof,$topicID,$description,$groups=array(),$perms=array()) {
 	if ($description) {
-		$topicID = $tof->ct->addTopic(array('ParentTopicID' => $topicID,
-											'Description' => $description));
+		createTopic($tof,$topicID,$description,'',$groups,$perms,false);
 	}
 	return $topicID;
 }
@@ -16,7 +15,7 @@ function createTopic(
 {
 	$topic = array('ParentTopicID' => $parentTopicID,
 				   'Description' => $description,
-				  'Summary' => $summary,
+				   'Summary' => $summary,
 				   'Book' => $book);
 	if ($book) {
 		global $papers;
@@ -36,8 +35,11 @@ function createTopic(
 
 	$topicID = $tof->ct->addTopic($topic);
 	$tof->ct->addTopicPerm($topicID,$tof->user['SelfGroup'],OWNER);
-	if (is_array($groups) && is_array($perms))
-		$tof->addTopicPerms($topicID,$groups,$perms);
+	if (is_array($groups) && is_array($perms)) {
+		require_once("actions/addTopicPerms.php");
+		addTopicPerms($tof,$topicID,$groups,$perms);
+	}
 	$tof->log(sprintf(_('Topic "%s" added.'),$tof->getTopicLink($description,$topicID)));
+	return $topicID;
 }
 ?>
\ No newline at end of file
