@@ -3,7 +3,7 @@ function _updateDates(&$tof,$vars) {
 	$overwrite = $vars['Overwrite'];
 	$pictures = $tof->ct->getPictures('PictureID,Date,RollID,FrameID');
 	foreach($pictures as $picture) {
-		  $tof->updateDate($picture,$overwrite);
+		  updateDate($tof,$picture,$overwrite);
 	}
 }
 
