@@ -7,6 +7,7 @@ function _updateDiskUsage(&$tof,$vars) {
 }
 
 function updateDiskUsage(&$tof,$userID = false) {
+	require_once("actions/disk_usage.php");
 	if ($userID === false) {
 		// compute for all users
 		echo "updateDiskUsage<br>";
@@ -16,7 +17,7 @@ function updateDiskUsage(&$tof,$userID = false) {
 		$tof->log(count($pictures)." pictures");
 		foreach($pictures as $picture) {
 			$owner = $picture['Owner'];
-			$du = $tof->getPictureDiskUsage($picture);
+			$du = getPictureDiskUsage($tof,$picture);
 			$total += $du;
 			$tof->log($picture['PictureID']."($owner) -> $du");
 			if (array_key_exists($owner,$diskUsages)) {
@@ -35,7 +36,7 @@ function updateDiskUsage(&$tof,$userID = false) {
 		$tof->log(
 			sprintf(_('Previous disk usage: %s'),
 					makeSizeString($user['DiskUsage'])));
-		$diskUsage = $tof->getDiskUsage($userID);
+		$diskUsage = getDiskUsage($tof,$userID);
 		$tof->log(
 			sprintf(_('New disk usage: %s'),
 					makeSizeString($diskUsage)));
