@@ -8,7 +8,7 @@ function _updatePictures(&$tof,$vars) {
 }
 
 /* update the groups and topic of a set of pictures */
-function updatePictures($parentTopicID, $groups, $pictures) {
+function updatePictures(&$tof,$parentTopicID, $groups, $pictures) {
 	$nbUpdatedPictures = 0;
 	if (!is_array($pictures)) {
 		return 0;
