@@ -5,9 +5,7 @@ function _updatePrefs(&$tof,$vars) {
 		'Email'=>$vars['Email'],
 		'PictureSize'=>$vars['PictureSize'],
 		'PictureInterval'=>$vars['PictureInterval'],
-		'NotifyComment'=>isset($vars['NotifyComment']),
-		'DisableTooltips'=>isset($vars['DisableTooltips']),
-		'ShowEmptyTopics'=>isset($vars['ShowEmptyTopics']));
+		'NotifyComment'=>isset($vars['NotifyComment']));
 
 	if ($vars['Password'] != $vars['ConfirmPassword']) {
 		$tof->error(_("Password and ConfirmPassword are different."));
