@@ -1,10 +1,11 @@
 <?php
 function _updateSelectionDates(&$tof,$vars) {
+	require_once("actions/updateDates.php");
 	$overwrite = $vars['Overwrite'];
 	$tof->log("updateSelectionDates");
 	list($count,$selection) = $tof->ct->getSelectedPictures($tof->uid);
 	foreach($selection as $picture) {
-		  $tof->updateDate($picture,$overwrite);
+		updateDate($tof,$picture,$overwrite);
 	}
 }
 ?>
\ No newline at end of file
