@@ -1,11 +1,21 @@
 <?php
+/**
+ * Upload a single image
+ */
 function _upload(&$tof,$vars) {
 	require_once("actions/roll.php");
 	require_once("actions/topic.php");
 	require_once("actions/uploads.php");
+
 	// TODO: We should check $_FILES['file']['error']
-	$rollID = $tof->maybeCreateRoll($vars['NewRollID'],$vars['RollID']);
-	$topicID = $tof->maybeCreateTopic($vars['ParentTopicID'],$vars['NewTopicDescription']);
+	$rollID = maybeCreateRoll($tof,$vars['NewRollID'],$vars['RollID']);
+	$topicID = maybeCreateTopic(
+		$tof,
+		$vars['ParentTopicID'],
+		$vars['NewTopicDescription'],
+		array(EVERYBODY),
+		array(READ,WRITE));
+
 	uploadFile(
 		$tof,
 		$_FILES['file']['tmp_name'],
