@@ -5,22 +5,23 @@ page_open(array("sess" => "Tof_Session",
 				"auth" => "Tof_Auth")); 
 
 $tof = new MySlooze($auth->auth['uid']);
-$tof->admin = true;
+$tof->setAdmin(true);
 $render = new BasicRender($tof);
 $tof->setRender($render);
 
-if ($uid == "") {
+require_once("render/page.php");
+
+if ($auth->auth['uid'] === "" || $auth->auth['uid'] === 0 || $auth->auth['uid'] == 'nobody') {
 	$render->error(
 		sprintf(
 			_("In order to access the admin pages, you must <a href=\"%s\">login.</a>"),
 			"$PHP_SELF?again=yes"));
-	renderErrorPage($render,$vars,$PHP_SELF);
+	renderMessagePage($render,$vars,$PHP_SELF);
 } else {
 	$vars = $tof->validateInputs();
 	$tof->handleAction($vars);
-	require_once("render/page.php");
 	renderPage($render,$vars,$PHP_SELF);
 }
 
-page_close() 
-?>
\ No newline at end of file
+page_close();
+?>
