@@ -17,7 +17,7 @@ if ($page) {
 } else {
 	$render->error("No such page ".$vars['PageNum']);
 	require_once("render/page.php");
-	renderErrorPage($render,$vars,$PHP_SELF);
+	renderMessagePage($render,$vars,$PHP_SELF);
 }
 // We do not close the page because of session concurrency issues:
 // page_open may have read old values of session variables, and we must not save them
