@@ -25,8 +25,8 @@ $render->show(
 showFormElementStart2(&$render,$vars['Target']);
 
 // THIS IS OBVIOUSLY A SECURITY ISSUE !!!
-eval('$params = '.$vars['Params'].';');
-foreach($params as $name => $value) {
+eval('$confirmParams = '.$vars['Params'].';');
+foreach($confirmParams as $name => $value) {
 	showFormElementHidden($render,$name,$value);
 }
 showButton($render,'Confirm',_('Yes'));
