@@ -11,14 +11,13 @@
 <body>
 
 <?php
-$uid=0;
-$mySlooze = new MySlooze($uid);
+$mySlooze = new MySlooze(0);
 $myRender = new BasicRender($mySlooze);
 $mySlooze->setRender($myRender);
 $vars = $mySlooze->validateInputs();
 $vars['action'] = 'remindPassword';
 $mySlooze->handleAction(&$vars);
-$myRender->showErrors();
+$myRender->showMessages();
 ?>
 
 <p>coucou gros ours.</p>
