@@ -15,7 +15,7 @@ $pictures = $ct->getPictures();
 reset($pictures);
 while(list($key,$picture) = each($pictures)) {
 	$pictureID = $picture['PictureID'];
-	$topics = $ct->getTopics($pictureID);
+	$topics = $ct->getTopicsOfPicture($pictureID);
 	if (count($topics)==1) {
 		$topic = $topics[0];
 		if ($topic['TopicID']!=0) {
